@@ -6,7 +6,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* This code uses an algorithm protected by U.S. Patent #4,405,829
@@ -62,15 +60,15 @@ static void
 test_keys( RSA_secret_key *sk, unsigned nbits )
 {
     RSA_public_key pk;
-    MPI test = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
-    MPI out1 = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
-    MPI out2 = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
+    MPI test = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
+    MPI out1 = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
+    MPI out2 = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
 
     pk.n = sk->n;
     pk.e = sk->e;
     {	char *p = get_random_bits( nbits, 0, 0 );
 	mpi_set_buffer( test, p, (nbits+7)/8, 0 );
-	m_free(p);
+	xfree(p);
     }
 
     public( out1, test, &pk );
@@ -107,7 +105,7 @@ generate( RSA_secret_key *sk, unsigned nbits )
     if ( (nbits&1) )
       nbits++; 
 
-    n = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
+    n = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
 
     p = q = NULL;
     do {
@@ -127,40 +125,36 @@ generate( RSA_secret_key *sk, unsigned nbits )
     /* calculate Euler totient: phi = (p-1)(q-1) */
     t1 = mpi_alloc_secure( mpi_get_nlimbs(p) );
     t2 = mpi_alloc_secure( mpi_get_nlimbs(p) );
-    phi = mpi_alloc_secure( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
-    g	= mpi_alloc_secure( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB  );
-    f	= mpi_alloc_secure( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB  );
+    phi = mpi_alloc_secure ( mpi_nlimb_hint_from_nbits (nbits) );
+    g	= mpi_alloc_secure ( mpi_nlimb_hint_from_nbits (nbits) );
+    f	= mpi_alloc_secure ( mpi_nlimb_hint_from_nbits (nbits) );
     mpi_sub_ui( t1, p, 1 );
     mpi_sub_ui( t2, q, 1 );
     mpi_mul( phi, t1, t2 );
     mpi_gcd(g, t1, t2);
     mpi_fdiv_q(f, phi, g);
 
-    /* find an public exponent.
-       We use 41 as this is quite fast and more secure than the
-       commonly used 17.  Benchmarking the RSA verify function
-       with a 1024 bit key yields (2001-11-08): 
+    /* Find an public exponent.
+       Benchmarking the RSA verify function with a 1024 bit key yields
+       (2001-11-08):
          e=17    0.54 ms
          e=41    0.75 ms
          e=257   0.95 ms
          e=65537 1.80 ms
+
+       This code used 41 until 2006-06-28 when it was changed to use
+       65537 as the new best practice.  See FIPS-186-3.
      */
-    e = mpi_alloc( (32+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
-    mpi_set_ui( e, 41); 
-    if( !mpi_gcd(t1, e, phi) ) {
-      mpi_set_ui( e, 257); 
-      if( !mpi_gcd(t1, e, phi) ) {
-        mpi_set_ui( e, 65537); 
-        while( !mpi_gcd(t1, e, phi) ) /* (while gcd is not 1) */
-          mpi_add_ui( e, e, 2);
-      }
-    }
+    e = mpi_alloc ( mpi_nlimb_hint_from_nbits (32) );
+    mpi_set_ui( e, 65537); 
+    while( !mpi_gcd(t1, e, phi) ) /* (while gcd is not 1) */
+      mpi_add_ui( e, e, 2);
 
     /* calculate the secret key d = e^1 mod phi */
-    d = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
+    d = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
     mpi_invm(d, e, f );
     /* calculate the inverse of p and q (used for chinese remainder theorem)*/
-    u = mpi_alloc( (nbits+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB );
+    u = mpi_alloc ( mpi_nlimb_hint_from_nbits (nbits) );
     mpi_invm(u, p, q );
 
     if( DBG_CIPHER ) {
@@ -355,7 +349,7 @@ rsa_generate( int algo, unsigned nbits, MPI *skey, MPI **retfactors )
     skey[5] = sk.u;
     /* make an empty list of factors */
     if (retfactors)
-      *retfactors = m_alloc_clear( 1 * sizeof **retfactors );
+      *retfactors = xmalloc_clear( 1 * sizeof **retfactors );
     return 0;
 }
 
@@ -447,7 +441,7 @@ rsa_verify( int algo, MPI hash, MPI *data, MPI *pkey )
 	return G10ERR_PUBKEY_ALGO;
     pk.n = pkey[0];
     pk.e = pkey[1];
-    result = mpi_alloc( (160+BITS_PER_MPI_LIMB-1)/BITS_PER_MPI_LIMB);
+    result = mpi_alloc ( mpi_nlimb_hint_from_nbits (160) );
     public( result, data[0], &pk );
     rc = mpi_cmp( result, hash )? G10ERR_BAD_SIGN:0;
     mpi_free(result);
