@@ -6,7 +6,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -34,6 +33,14 @@
 #include "keydb.h"
 #include "i18n.h"
 
+#ifdef HAVE_UNSIGNED_TIME_T
+# define INVALID_TIME_CHECK(a) ((a) == (time_t)(-1))
+#else
+  /* Error or 32 bit time_t and value after 2038-01-19.  */
+# define INVALID_TIME_CHECK(a) ((a) < 0)
+#endif
+
+
 int
 pubkey_letter( int algo )
 {
@@ -44,6 +51,8 @@ pubkey_letter( int algo )
       case PUBKEY_ALGO_ELGAMAL_E: return 'g';
       case PUBKEY_ALGO_ELGAMAL: return 'G' ;
       case PUBKEY_ALGO_DSA:	return 'D' ;
+      case PUBKEY_ALGO_ECDSA:	return 'E' ;	/* ECC DSA (sign only)   */
+      case PUBKEY_ALGO_ECDH:	return 'e' ;	/* ECC DH (encrypt only) */
       default: return '?';
     }
 }
@@ -93,7 +102,7 @@ hash_public_key( MD_HANDLE md, PKT_public_key *pk )
       u16 days=0;
       if(pk->expiredate)
 	days=(u16)((pk->expiredate - pk->timestamp) / 86400L);
- 
+
       md_putc( md, days >> 8 );
       md_putc( md, days );
     }
@@ -108,7 +117,7 @@ hash_public_key( MD_HANDLE md, PKT_public_key *pk )
 	md_putc( md, nb[i]>>8);
 	md_putc( md, nb[i] );
 	md_write( md, pp[i], nn[i] );
-	m_free(pp[i]);
+	xfree(pp[i]);
       }
 }
 
@@ -168,7 +177,7 @@ keystrlen(void)
 
 const char *
 keystr(u32 *keyid)
-{  
+{
   static char keyid_str[19];
 
   switch(opt.keyid_format)
@@ -411,7 +420,7 @@ namehash_from_uid(PKT_user_id *uid)
 {
   if(uid->namehash==NULL)
     {
-      uid->namehash=m_alloc(20);
+      uid->namehash=xmalloc(20);
 
       if(uid->attrib_data)
 	rmd160_hash_buffer(uid->namehash,uid->attrib_data,uid->attrib_len);
@@ -445,8 +454,8 @@ mk_datestr (char *buffer, time_t atime)
 {
     struct tm *tp;
 
-    if ( atime < 0 ) /* 32 bit time_t and after 2038-01-19 */
-        strcpy (buffer, "????" "-??" "-??"); /* mark this as invalid */
+    if (INVALID_TIME_CHECK (atime))
+      strcpy (buffer, "????" "-??" "-??"); /* Mark this as invalid.  */
     else {
         tp = gmtime (&atime);
         sprintf (buffer,"%04d-%02d-%02d",
@@ -542,13 +551,12 @@ usagestr_from_pk( PKT_public_key *pk )
   static char buffer[10];
   int i = 0;
   unsigned int use = pk->pubkey_usage;
-    
+
   if ( use & PUBKEY_USAGE_SIG )
-    {
-      if (pk->is_primary)
-        buffer[i++] = 'C';
-      buffer[i++] = 'S';
-    }
+    buffer[i++] = 'S';
+
+  if ( use & PUBKEY_USAGE_CERT )
+    buffer[i++] = 'C';
 
   if ( use & PUBKEY_USAGE_ENC )
     buffer[i++] = 'E';
@@ -649,14 +657,14 @@ fingerprint_from_pk( PKT_public_key *pk, byte *array, size_t *ret_len )
 	    if( pubkey_get_npkey( pk->pubkey_algo ) > 1 ) {
 	      p = buf = mpi_get_buffer( pk->pkey[0], &n, NULL );
 	      md_write( md, p, n );
-	      m_free(buf);
+	      xfree(buf);
 	      p = buf = mpi_get_buffer( pk->pkey[1], &n, NULL );
 	      md_write( md, p, n );
-	      m_free(buf);
+	      xfree(buf);
 	    }
 	    md_final(md);
 	    if( !array )
-	      array = m_alloc( 16 );
+	      array = xmalloc( 16 );
 	    len = 16;
 	    memcpy(array, md_read(md, DIGEST_ALGO_MD5), 16 );
 	    md_close(md);
@@ -664,7 +672,7 @@ fingerprint_from_pk( PKT_public_key *pk, byte *array, size_t *ret_len )
 	else
 	  {
 	    if(!array)
-	      array=m_alloc(16);
+	      array=xmalloc(16);
 	    len=16;
 	    memset(array,0,16);
 	  }
@@ -676,7 +684,7 @@ fingerprint_from_pk( PKT_public_key *pk, byte *array, size_t *ret_len )
 	len = md_digest_length( md_get_algo( md ) );
 	assert( len <= MAX_FINGERPRINT_LEN );
 	if( !array )
-	    array = m_alloc( len );
+	    array = xmalloc( len );
 	memcpy(array, dp, len );
 	pk->keyid[0] = dp[12] << 24 | dp[13] << 16 | dp[14] << 8 | dp[15] ;
 	pk->keyid[1] = dp[16] << 24 | dp[17] << 16 | dp[18] << 8 | dp[19] ;
@@ -706,14 +714,14 @@ fingerprint_from_sk( PKT_secret_key *sk, byte *array, size_t *ret_len )
 	    if( pubkey_get_npkey( sk->pubkey_algo ) > 1 ) {
 	      p = buf = mpi_get_buffer( sk->skey[0], &n, NULL );
 	      md_write( md, p, n );
-	      m_free(buf);
+	      xfree(buf);
 	      p = buf = mpi_get_buffer( sk->skey[1], &n, NULL );
 	      md_write( md, p, n );
-	      m_free(buf);
+	      xfree(buf);
 	    }
 	    md_final(md);
 	    if( !array )
-	      array = m_alloc( 16 );
+	      array = xmalloc( 16 );
 	    len = 16;
 	    memcpy(array, md_read(md, DIGEST_ALGO_MD5), 16 );
 	    md_close(md);
@@ -721,7 +729,7 @@ fingerprint_from_sk( PKT_secret_key *sk, byte *array, size_t *ret_len )
 	else
 	  {
 	    if(!array)
-	      array=m_alloc(16);
+	      array=xmalloc(16);
 	    len=16;
 	    memset(array,0,16);
 	  }
@@ -735,7 +743,7 @@ fingerprint_from_sk( PKT_secret_key *sk, byte *array, size_t *ret_len )
 	    len = md_digest_length( md_get_algo( md ) );
 	    assert( len <= MAX_FINGERPRINT_LEN );
 	    if( !array )
-	      array = m_alloc( len );
+	      array = xmalloc( len );
 	    memcpy(array, dp, len );
 	    md_close(md);
 	  }
@@ -743,7 +751,7 @@ fingerprint_from_sk( PKT_secret_key *sk, byte *array, size_t *ret_len )
 	  {
 	    len=MAX_FINGERPRINT_LEN;
 	    if(!array)
-	      array=m_alloc(len);
+	      array=xmalloc(len);
 	    memset(array,0,len);
 	  }
     }
