@@ -6,7 +6,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -15,9 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -77,7 +75,7 @@ progress_cb ( void *ctx, int c )
 }
 
 static const char *
-get_status_string ( int no ) 
+get_status_string ( int no )
 {
   const char *s;
 
@@ -166,6 +164,8 @@ get_status_string ( int no )
     case STATUS_PKA_TRUST_BAD  : s = "PKA_TRUST_BAD"; break;
     case STATUS_PKA_TRUST_GOOD : s = "PKA_TRUST_GOOD"; break;
     case STATUS_BEGIN_SIGNING  : s = "BEGIN_SIGNING"; break;
+    case STATUS_ERROR          : s = "ERROR"; break;
+    case STATUS_DECRYPTION_INFO: s = "DECRYPTION_INFO"; break;
     default: s = "?"; break;
     }
   return s;
@@ -188,13 +188,13 @@ status_currently_allowed (int no)
      prompt the user. */
   switch (no)
     {
-    case STATUS_GET_BOOL:	 
-    case STATUS_GET_LINE:	 
-    case STATUS_GET_HIDDEN:	 
-    case STATUS_GOT_IT:	 
+    case STATUS_GET_BOOL:
+    case STATUS_GET_LINE:
+    case STATUS_GET_HIDDEN:
+    case STATUS_GOT_IT:
     case STATUS_IMPORTED:
-    case STATUS_IMPORT_OK:	
-    case STATUS_IMPORT_CHECK:  
+    case STATUS_IMPORT_OK:
+    case STATUS_IMPORT_CHECK:
     case STATUS_IMPORT_RES:
       return 1; /* Yes. */
     default:
@@ -215,7 +215,7 @@ set_status_fd ( int fd )
     if ( statusfp && statusfp != stdout && statusfp != stderr )
         fclose (statusfp);
     statusfp = NULL;
-    if ( fd == -1 ) 
+    if ( fd == -1 )
         return;
 
     if( fd == 1 )
@@ -261,7 +261,7 @@ write_status_text ( int no, const char *text)
                 fputs ( "\\n", statusfp );
             else if (*text == '\r')
                 fputs ( "\\r", statusfp );
-            else 
+            else
                 putc ( *(const byte *)text,  statusfp );
         }
     }
@@ -288,7 +288,7 @@ write_status_text_and_buffer ( int no, const char *string,
 
     if( !statusfp || !status_currently_allowed (no) )
 	return;  /* Not enabled or allowed. */
-    
+
     if (wrap == -1) {
         lower_limit--;
         wrap = 0;
@@ -307,8 +307,8 @@ write_status_text_and_buffer ( int no, const char *string,
             first = 0;
         }
         for (esc=0, s=buffer, n=len; n && !esc; s++, n-- ) {
-            if ( *s == '%' || *(const byte*)s <= lower_limit 
-                           || *(const byte*)s == 127 ) 
+            if ( *s == '%' || *(const byte*)s <= lower_limit
+                           || *(const byte*)s == 127 )
                 esc = 1;
             if ( wrap && ++count > wrap ) {
                 dowrap=1;
@@ -318,7 +318,7 @@ write_status_text_and_buffer ( int no, const char *string,
         if (esc) {
             s--; n++;
         }
-        if (s != buffer) 
+        if (s != buffer)
             fwrite (buffer, s-buffer, 1, statusfp );
         if ( esc ) {
             fprintf (statusfp, "%%%02X", *(const byte*)s );
@@ -469,10 +469,10 @@ init_shm_coprocessing ( ulong requested_shm_size, int lock_mem )
 
 /****************
  * Request a string from client
- * If bool, returns static string on true (do not free) or NULL for false
+ * If GETBOOL, returns static string on true (do not free) or NULL for false
  */
 static char *
-do_shm_get( const char *keyword, int hidden, int bool )
+do_shm_get( const char *keyword, int hidden, int getbool )
 {
     size_t n;
     byte *p;
@@ -486,7 +486,7 @@ do_shm_get( const char *keyword, int hidden, int bool )
     shm_area[2] = 1;  /* indicate that we are waiting on a reply */
     shm_area[3] = 0;  /* clear data available flag */
 
-    write_status_text( bool? STATUS_SHM_GET_BOOL :
+    write_status_text( getbool? STATUS_SHM_GET_BOOL :
 		       hidden? STATUS_SHM_GET_HIDDEN : STATUS_SHM_GET, keyword );
 
     do {
@@ -501,7 +501,7 @@ do_shm_get( const char *keyword, int hidden, int bool )
     if( n+32+2+1 > 4095 )
 	log_fatal("client returns too large data (%u bytes)\n", (unsigned)n );
 
-    if( bool )
+    if( getbool )
 	return p[0]? "" : NULL;
 
     string = hidden? xmalloc_secure( n+1 ) : xmalloc( n+1 );
@@ -536,7 +536,7 @@ myread(int fd, void *buf, size_t count)
             raise (SIGHUP); /* no more input data */
 #endif
         }
-    }    
+    }
     return rc;
 }
 
@@ -544,10 +544,10 @@ myread(int fd, void *buf, size_t count)
 
 /****************
  * Request a string from the client over the command-fd
- * If bool, returns static string on true (do not free) or NULL for false
+ * If getbool, returns static string on true (do not free) or NULL for false
  */
 static char *
-do_get_from_fd( const char *keyword, int hidden, int bool )
+do_get_from_fd( const char *keyword, int hidden, int getbool )
 {
     int i, len;
     char *string;
@@ -555,7 +555,7 @@ do_get_from_fd( const char *keyword, int hidden, int bool )
     if(statusfp!=stdout)
       fflush(stdout);
 
-    write_status_text( bool? STATUS_GET_BOOL :
+    write_status_text( getbool? STATUS_GET_BOOL :
 		       hidden? STATUS_GET_HIDDEN : STATUS_GET_LINE, keyword );
 
     for( string = NULL, i = len = 200; ; i++ ) {
@@ -582,7 +582,7 @@ do_get_from_fd( const char *keyword, int hidden, int bool )
 
     write_status( STATUS_GOT_IT );
 
-    if( bool )	 /* Fixme: is this correct??? */
+    if( getbool )	 /* Fixme: is this correct??? */
 	return (string[0] == 'Y' || string[0] == 'y') ? "" : NULL;
 
     return string;
